==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/ja-JP/localizations.php <==
<?php

return [

    'select_language' => '言語を選択',
    'languages' => [
        'en-US'=> '英語 (アメリカ)',
        'en-GB'=> '英語 (イギリス)',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Arabic',
        'bg-BG'=> 'Bulgarian',
        'zh-CN'=> '中国語 (簡体字)',
        'zh-TW'=> '中国語(繁体字)',
        'ca-ES' => 'カタロニア語',
        'hr-HR'=> 'Croatian',
        'cs-CZ'=> 'Czech',
        'da-DK'=> 'Danish',
        'nl-NL'=> 'Dutch',
        'en-ID'=> '英語(インドネシア)',
        'et-EE'=> 'Estonian',
        'fil-PH'=> 'Filipino',
        'fi-FI'=> 'Finnish',
        'fr-FR'=> 'French',
        'de-DE'=> 'ドイツ語',
        'de-if'=> 'ドイツ語 (非公式)',
        'el-GR'=> 'Greek',
        'he-IL'=> 'Hebrew',
        'hu-HU'=> 'Hungarian',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Indonesian',
        'ga-IE'=> 'Irish',
        'it-IT'=> 'Italian',
        'ja-JP'=> '日本語',
        'km-KH'=>'Khmer',
        'ko-KR'=> '韓国語',
        'lt-LT'=>'Lithuanian',
        'lv-LV'=> 'Latvian',
        'mk-MK'=> 'Macedonian',
        'ms-MY'=> 'Malay',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongolian',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persian',
        'pl-PL'=> 'Polish',
        'pt-PT'=> 'Portuguese',
        'pt-BR'=> 'Portuguese, Brazilian',
        'ro-RO'=> 'Romanian',
        'ru-RU'=> 'Russian',
        'sr-CS' => 'Serbian (Latin)',
        'sk-SK'=> 'スロバキア語',
        'sl-SI'=> 'Slovenian',
        'so-SO'=> 'ソマリ語',
        'es-ES'=> 'Spanish',
        'es-CO'=> 'Spanish, Colombia',
        'es-MX'=> 'Spanish, Mexico',
        'es-VE'=> 'Spanish, Venezuela',
        'sv-SE'=> 'Swedish',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Turkish',
        'uk-UA'=> 'Ukranian',
        'vi-VN'=> 'Vietnamese',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => '国を選択',
    
    'countries' => [
        'AC'=>'Ascension Island',
        'AD'=>'Andorra',
        'AE'=>'アラブ首長国連邦',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua And Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Netherlands Antilles',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentina',
        'AS'=>'American Samoa',
        'AT'=>'オーストリア',
        'AU'=>'オーストラリア',
        'AW'=>'Aruba',
        'AX'=>'Ãƒâ€¦land',
        'AZ'=>'Azerbaijan',
        'BA'=>'Bosnia And Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgium',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brazil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet Island',
        'BW'=>'Botswana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'カナダ',
        'CC'=>'Cocos (Keeling) Islands',
        'CD'=>'Congo (Democratic Republic)',
        'CF'=>'Central African Republic',
        'CG'=>'Congo (Republic)',
        'CH'=>'Switzerland',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Cook Islands',
        'CL'=>'Chile',
        'CM'=>'Cameroon',
        'CN'=>'People\'s Republic of China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Island',
        'CY'=>'Cyprus',
        'CZ'=>'Czech Republic',
        'DE'=>'Germany',
        'DJ'=>'Djibouti',
        'DK'=>'Denmark',
        'DM'=>'Dominica',
        'DO'=>'Dominican Republic',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egypt',
        'GB-ENG'=>'England',
        'ER'=>'Eritrea',
        'ES'=>'Spain',
        'ET'=>'Ethiopia',
        'EU'=>'European Union',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falkland Islands (Malvinas)',
        'FM'=>'Micronesia, Federated States Of',
        'FO'=>'Faroe Islands',
        'FR'=>'France',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'French Guiana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Greenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Greece',
        'GS'=>'South Georgia And The South Sandwich Islands',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'香港',
        'HM'=>'Heard And Mc Donald Islands',
        'HN'=>'Honduras',
        'HR'=>'Croatia (local name: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Hungary',
        'ID'=>'Indonesia',
        'IE'=>'Ireland',
        'IL'=>'イスラエル',
        'IM'=>'Isle of Man',
        'IN'=>'インド',
        'IO'=>'British Indian Ocean Territory',
        'IQ'=>'Iraq',
        'IR'=>'Iran, Islamic Republic Of',
        'IS'=>'Iceland',
        'IT'=>'Italy',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'日本',
        'KE'=>'Kenya',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Cambodia',
        'KI'=>'Kiribati',
        'KM'=>'Comoros',
        'KN'=>'Saint Kitts And Nevis',
        'KR'=>'韓国',
        'KW'=>'Kuwait',
        'KY'=>'ケイマン諸島',
        'KZ'=>'Kazakhstan',
        'LA'=>'ラオス人民民主共和国',
        'LB'=>'Lebanon',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxembourg',
        'LV'=>'Latvia',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Morocco',
        'MC'=>'Monaco',
        'MD'=>'Moldova, Republic Of',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Marshall Islands',
        'MK'=>'Macedonia, The Former Yugoslav Republic Of',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'マカオ',
        'MP'=>'Northern Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolk Island',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Netherlands',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'French Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Philippines, Republic of the',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre And Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russian Federation',
        'RW'=>'Rwanda',
        'SA'=>'Saudi Arabia',
        'GB-SCT'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'Seychelles',
        'SS'=>'南スーダン',
        'SD'=>'Sudan',
        'SE'=>'Sweden',
        'SG'=>'シンガポール',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard And Jan Mayen Islands',
        'SK'=>'Slovakia (Slovak Republic)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome And Principe',
        'SU'=>'Soviet Union',
        'SV'=>'El Salvador',
        'SY'=>'Syrian Arab Republic',
        'SZ'=>'Swaziland',
        'TC'=>'Turks And Caicos Islands',
        'TD'=>'Chad',
        'TF'=>'French Southern Territories',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'East Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (old code)',
        'TR'=>'Turkey',
        'TT'=>'Trinidad And Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'台湾',
        'TZ'=>'Tanzania, United Republic Of',
        'UA'=>'ウクライナ',
        'UG'=>'Uganda',
        'UK'=>'イギリス',
        'US'=>'アメリカ',
        'UM'=>'United States Minor Outlying Islands',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatican City State (Holy See)',
        'VC'=>'Saint Vincent And The Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Islands (British)',
        'VI'=>'Virgin Islands (U.S.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis And Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/ja-JP/localizations.php <==
<?php

return [

    'select_language' => '言語を選択',
    'languages' => [
        'en-US'=> '英語 (アメリカ)',
        'en-GB'=> '英語 (イギリス)',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Afrikaans',
        'ar-SA'=> 'Arabic',
        'bg-BG'=> 'Bulgarian',
        'zh-CN'=> '中国語 (簡体字)',
        'zh-TW'=> '中国語(繁体字)',
        'ca-ES' => 'カタロニア語',
        'hr-HR'=> 'Croatian',
        'cs-CZ'=> 'Czech',
        'da-DK'=> 'Danish',
        'nl-NL'=> 'Dutch',
        'en-ID'=> '英語(インドネシア)',
        'et-EE'=> 'Estonian',
        'fil-PH'=> 'Filipino',
        'fi-FI'=> 'Finnish',
        'fr-FR'=> 'French',
        'de-DE'=> 'ドイツ語',
        'de-if'=> 'ドイツ語 (非公式)',
        'el-GR'=> 'Greek',
        'he-IL'=> 'Hebrew',
        'hu-HU'=> 'Hungarian',
        'is-IS' => 'Icelandic',
        'id-ID'=> 'Indonesian',
        'ga-IE'=> 'Irish',
        'it-IT'=> 'Italian',
        'ja-JP'=> '日本語',
        'km-KH'=>'Khmer',
        'ko-KR'=> '韓国語',
        'lt-LT'=>'Lithuanian',
        'lv-LV'=> 'Latvian',
        'mk-MK'=> 'Macedonian',
        'ms-MY'=> 'Malay',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongolian',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'ノルウェー語ブークモール',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persian',
        'pl-PL'=> 'Polish',
        'pt-PT'=> 'Portuguese',
        'pt-BR'=> 'Portuguese, Brazilian',
        'ro-RO'=> 'Romanian',
        'ru-RU'=> 'Russian',
        'sr-CS' => 'Serbian (Latin)',
        'sk-SK'=> 'スロバキア語',
        'sl-SI'=> 'Slovenian',
        'so-SO'=> 'ソマリ語',
        'es-ES'=> 'Spanish',
        'es-CO'=> 'Spanish, Colombia',
        'es-MX'=> 'Spanish, Mexico',
        'es-VE'=> 'Spanish, Venezuela',
        'sv-SE'=> 'Swedish',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Turkish',
        'uk-UA'=> 'Ukranian',
        'vi-VN'=> 'Vietnamese',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => '国を選択',
    
    'countries' => [
        'AC'=>'Ascension Island',
        'AD'=>'Andorra',
        'AE'=>'アラブ首長国連邦',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua And Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Netherlands Antilles',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentina',
        'AS'=>'American Samoa',
        'AT'=>'オーストリア',
        'AU'=>'オーストラリア',
        'AW'=>'Aruba',
        'AX'=>'Ãƒâ€¦land',
        'AZ'=>'Azerbaijan',
        'BA'=>'Bosnia And Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgium',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brazil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet Island',
        'BW'=>'Botswana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'カナダ',
        'CC'=>'Cocos (Keeling) Islands',
        'CD'=>'Congo (Democratic Republic)',
        'CF'=>'Central African Republic',
        'CG'=>'Congo (Republic)',
        'CH'=>'Switzerland',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Cook Islands',
        'CL'=>'Chile',
        'CM'=>'Cameroon',
        'CN'=>'People\'s Republic of China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Island',
        'CY'=>'Cyprus',
        'CZ'=>'Czech Republic',
        'DE'=>'Germany',
        'DJ'=>'Djibouti',
        'DK'=>'Denmark',
        'DM'=>'Dominica',
        'DO'=>'Dominican Republic',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egypt',
        'GB-ENG'=>'イングランド',
        'ER'=>'Eritrea',
        'ES'=>'Spain',
        'ET'=>'Ethiopia',
        'EU'=>'European Union',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falkland Islands (Malvinas)',
        'FM'=>'Micronesia, Federated States Of',
        'FO'=>'Faroe Islands',
        'FR'=>'France',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'French Guiana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Greenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Greece',
        'GS'=>'South Georgia And The South Sandwich Islands',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'香港',
        'HM'=>'Heard And Mc Donald Islands',
        'HN'=>'Honduras',
        'HR'=>'Croatia (local name: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Hungary',
        'ID'=>'Indonesia',
        'IE'=>'Ireland',
        'IL'=>'イスラエル',
        'IM'=>'Isle of Man',
        'IN'=>'インド',
        'IO'=>'British Indian Ocean Territory',
        'IQ'=>'Iraq',
        'IR'=>'Iran, Islamic Republic Of',
        'IS'=>'Iceland',
        'IT'=>'Italy',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'日本',
        'KE'=>'Kenya',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Cambodia',
        'KI'=>'Kiribati',
        'KM'=>'Comoros',
        'KN'=>'Saint Kitts And Nevis',
        'KR'=>'韓国',
        'KW'=>'Kuwait',
        'KY'=>'ケイマン諸島',
        'KZ'=>'Kazakhstan',
        'LA'=>'ラオス人民民主共和国',
        'LB'=>'Lebanon',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxembourg',
        'LV'=>'Latvia',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Morocco',
        'MC'=>'Monaco',
        'MD'=>'Moldova, Republic Of',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Marshall Islands',
        'MK'=>'Macedonia, The Former Yugoslav Republic Of',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'マカオ',
        'MP'=>'Northern Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolk Island',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Netherlands',
        'GB-NIR' => '北アイルランド',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'French Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Philippines, Republic of the',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre And Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russian Federation',
        'RW'=>'Rwanda',
        'SA'=>'Saudi Arabia',
        'GB-SCT'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'Seychelles',
        'SS'=>'南スーダン',
        'SD'=>'Sudan',
        'SE'=>'Sweden',
        'SG'=>'シンガポール',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard And Jan Mayen Islands',
        'SK'=>'Slovakia (Slovak Republic)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome And Principe',
        'SU'=>'Soviet Union',
        'SV'=>'El Salvador',
        'SY'=>'Syrian Arab Republic',
        'SZ'=>'Swaziland',
        'TC'=>'Turks And Caicos Islands',
        'TD'=>'Chad',
        'TF'=>'French Southern Territories',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'East Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (old code)',
        'TR'=>'Turkey',
        'TT'=>'Trinidad And Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'台湾',
        'TZ'=>'Tanzania, United Republic Of',
        'UA'=>'ウクライナ',
        'UG'=>'Uganda',
        'UK'=>'イギリス',
        'US'=>'アメリカ',
        'UM'=>'United States Minor Outlying Islands',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatican City State (Holy See)',
        'VC'=>'Saint Vincent And The Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Islands (British)',
        'VI'=>'Virgin Islands (U.S.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'ウェールズ',
        'WF'=>'Wallis And Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
